# major is the part of the library name after the .so
%define major 2
%define libname %mklibname sepol %{major}
%define develname %mklibname sepol -d
%define stdevelname %mklibname sepol -d -s
%define _legacy_common_support 1

Summary: SELinux binary policy manipulation library
Name: libsepol
Version: 3.4
Release: %mkrel 4
Group: System/Libraries
License: LGPLv2+
Source0: https://github.com/SELinuxProject/selinux/releases/download/3.4/libsepol-3.4.tar.gz
URL: https://github.com/SELinuxProject/selinux/wiki
# $ git clone https://github.com/fedora-selinux/selinux.git
# $ cd selinux
# $ git format-patch -N libsepol-3.4 -- libsepol
# $ i=1; for j in 0*patch; do printf "Patch%04d: %s\n" $i $j; i=$((i+1));done
# Patch list start
# Patch list end
BuildRequires: make
BuildRequires: gcc
BuildRequires: flex
Obsoletes: %{name}-compat = 3.1-4

%description
Security-enhanced Linux is a feature of the Linux® kernel and a number
of utilities with enhanced security functionality designed to add
mandatory access controls to Linux.  The Security-enhanced Linux
kernel contains new architectural components originally developed to
improve the security of the Flask operating system. These
architectural components provide general support for the enforcement
of many kinds of mandatory access control policies, including those
based on the concepts of Type Enforcement®, Role-based Access
Control, and Multi-level Security.

libsepol provides an API for the manipulation of SELinux binary policies.
It is used by checkpolicy (the policy compiler) and similar tools, as well
as by programs like load_policy that need to perform specific transformations
on binary policies such as customizing policy boolean settings.

%package -n %{libname}
Summary: SELinux binary policy manipulation library
Group: System/Libraries
Provides: libsepol = %{version}-%{release}
Provides: libsepol%{?_isa} = %{version}-%{release}

%description -n %{libname}
libsepol provides an API for the manipulation of SELinux binary policies.
It is used by checkpolicy (the policy compiler) and similar tools, as well
as by programs like load_policy that need to perform specific transformations
on binary policies such as customizing policy boolean settings.


%package -n %{develname}
Summary: Header files and libraries used to build policy manipulation tools
Requires: %{libname} = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}
Provides: sepol-devel = %{version}-%{release}

%description -n %{develname}
The libsepol-devel package contains the libraries and header files
needed for developing applications that manipulate binary policies.

%package -n %{stdevelname}
Summary: static libraries used to build policy manipulation tools
Requires: %{develname} = %{version}-%{release}
Provides: %{name}-static-devel = %{version}-%{release}
Provides: sepol-static-devel = %{version}-%{release}

%description -n %{stdevelname}
The libsepol-static package contains the static libraries and header files
needed for developing applications that manipulate binary policies.

%package utils
Summary: SELinux libsepol utilities
Requires: %{name}%{?_isa} = %{version}-%{release}

%description utils
The libsepol-utils package contains the utilities

%prep
%autosetup -p 2 -n libsepol-%{version}

# sparc64 is an -fPIC arch, so we need to fix it here
%ifarch sparc64
sed -i 's/fpic/fPIC/g' src/Makefile
%endif

%build
%set_build_flags
CFLAGS="$CFLAGS -fno-semantic-interposition"
%make_build LIBDIR="%{_libdir}"

%install
mkdir -p ${RPM_BUILD_ROOT}%{_libdir}
mkdir -p ${RPM_BUILD_ROOT}%{_includedir}
mkdir -p ${RPM_BUILD_ROOT}%{_bindir}
mkdir -p ${RPM_BUILD_ROOT}%{_mandir}/man3
mkdir -p ${RPM_BUILD_ROOT}%{_mandir}/man8
%make_install LIBDIR="%{_libdir}" SHLIBDIR="%{_libdir}"
rm -rf ${RPM_BUILD_ROOT}%{_mandir}/man8/gen*
rm -rf ${RPM_BUILD_ROOT}%{_mandir}/ru/man8

%files -n %{stdevelname}
%{_libdir}/libsepol.a

%files -n %{develname}
%{_libdir}/libsepol.so
%{_libdir}/pkgconfig/libsepol.pc
%{_includedir}/sepol/*.h
%{_mandir}/man3/*.3.*
%dir %{_includedir}/sepol
%dir %{_includedir}/sepol/policydb
%{_includedir}/sepol/policydb/*.h
%dir %{_includedir}/sepol/cil
%{_includedir}/sepol/cil/*.h

%files -n %{libname}
%{_libdir}/libsepol.so.%{major}

%files utils
%{_bindir}/chkcon
%{_bindir}/sepol_check_access
%{_bindir}/sepol_compute_av
%{_bindir}/sepol_compute_member
%{_bindir}/sepol_compute_relabel
%{_bindir}/sepol_validate_transition
%{_mandir}/man8/chkcon.8.*



%changelog
* Mon Oct 10 2022 wally <wally> 3.4-4.mga9
+ Revision: 1896153
- restore devel pkg requires and provides

* Sun Oct 09 2022 neoclust <neoclust> 3.4-3.mga9
+ Revision: 1895972
- Add provides for the static devel package

* Sun Oct 09 2022 neoclust <neoclust> 3.4-2.mga9
+ Revision: 1895971
- Fix requires in the static devel package

* Sun Oct 09 2022 neoclust <neoclust> 3.4-1.mga9
+ Revision: 1895945
- New version 3.4

* Fri Mar 18 2022 umeabot <umeabot> 3.2-0.rc1.6.mga9
+ Revision: 1797877
- Mageia 9 Mass Rebuild

* Thu Dec 30 2021 neoclust <neoclust> 3.2-0.rc1.5.mga9
+ Revision: 1765507
- Add P100 -> 102: Fixes CVE-2021-3608[4-6] (mga#29664)

* Fri Jan 29 2021 neoclust <neoclust> 3.2-0.rc1.4.mga8
+ Revision: 1673942
- Add missing provide in libsepol lib package

* Fri Jan 29 2021 neoclust <neoclust> 3.2-0.rc1.3.mga8
+ Revision: 1673937
- Fix provides/Requires
- Fix require name on the devel package

* Fri Jan 29 2021 neoclust <neoclust> 3.2-0.rc1.1.mga8
+ Revision: 1673930
- New version 3.2-rc1

* Tue Aug 04 2020 joequant <joequant> 2.5-4.mga8
+ Revision: 1611001
- redo deps
- redo deps

* Thu Feb 13 2020 umeabot <umeabot> 2.5-3.mga8
+ Revision: 1514409
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Sun Sep 23 2018 umeabot <umeabot> 2.5-2.mga7
+ Revision: 1299140
- Mageia 7 Mass Rebuild

* Thu Feb 25 2016 spuhler <spuhler> 2.5-1.mga6
+ Revision: 979087
-u pgrade to vers. 2.5

* Mon Feb 15 2016 umeabot <umeabot> 2.4-2.mga6
+ Revision: 961214
- Mageia 6 Mass Rebuild

* Sun Nov 01 2015 tv <tv> 2.4-1.mga6
+ Revision: 897006
- adjust file list
- BR flex
- new release
- fix source URL

* Wed Oct 15 2014 umeabot <umeabot> 2.3-5.mga5
+ Revision: 739473
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.3-4.mga5
+ Revision: 681776
- Mageia 5 Mass Rebuild

* Mon Sep 15 2014 wally <wally> 2.3-3.mga5
+ Revision: 676786
- add some generic provides to devel pkgs
- fix static devel pkg requires

* Sun Sep 14 2014 spuhler <spuhler> 2.3-2.mga5
+ Revision: 675520
- changed the library names to meet Mageia spec

* Thu Jun 12 2014 spuhler <spuhler> 2.3-1.mga5
+ Revision: 635724
- upgrade to ver. 2.3

* Thu Feb 06 2014 spuhler <spuhler> 2.2-1.mga5
+ Revision: 584060
- upgrade to ver 2.2

* Fri Oct 18 2013 umeabot <umeabot> 2.1.9-3.mga4
+ Revision: 522441
- Mageia 4 Mass Rebuild

* Fri Mar 01 2013 spuhler <spuhler> 2.1.9-2.mga3
+ Revision: 400907
- added Provides: libsepol = %%{version}-%%{release}
 * to make the Requires arch independent

* Tue Feb 26 2013 spuhler <spuhler> 2.1.9-1.mga3
+ Revision: 400392
- upgrade to 2.1.9
  filename_trans: use some better sorting to compare and merge
  coverity fixes
  implement default type policy syntax
  Fix memory leak issues found by Klocwork
- updated patch from rhat for 2.1.9

* Sat Jan 12 2013 umeabot <umeabot> 2.1.8-3.mga3
+ Revision: 358139
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 04 2013 spuhler <spuhler> 2.1.8-2.mga3
+ Revision: 338495
- bumped rel to build it with updated patch
- updated rhat.patch

* Sat Dec 01 2012 spuhler <spuhler> 2.1.8-1.mga3
+ Revision: 324422
- upgrade to 2.1.8
  cleanup of spec

* Sun Sep 02 2012 spuhler <spuhler> 2.1.7-1.mga3
+ Revision: 287138
- update to 2.1.7
- added libsepol-rhat.patch

* Fri Feb 11 2011 dmorgan <dmorgan> 2.0.34-2.mga1
+ Revision: 50044
- Fix typo
- Fix file list
- Remove mdv macros
- imported package libsepol


* Sun Sep 13 2009 Thierry Vignaud <tvignaud@mandriva.com> 2.0.34-2mdv2010.0
+ Revision: 438739
- rebuild

* Sun Nov 30 2008 David Walluck <walluck@mandriva.org> 2.0.34-1mdv2009.1
+ Revision: 308330
- 2.0.34

* Mon Nov 24 2008 David Walluck <walluck@mandriva.org> 2.0.33-1mdv2009.1
+ Revision: 306134
- 2.0.33

* Mon Jul 28 2008 David Walluck <walluck@mandriva.org> 2.0.32-1mdv2009.0
+ Revision: 250775
- don't include .sign file
- 2.0.32

* Sun Jul 27 2008 David Walluck <walluck@mandriva.org> 2.0.30-1mdv2009.0
+ Revision: 250494
- 2.0.30

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sun Apr 20 2008 David Walluck <walluck@mandriva.org> 2.0.25-1mdv2009.0
+ Revision: 195979
- 2.0.25

* Fri Jan 04 2008 David Walluck <walluck@mandriva.org> 2.0.11-2mdv2008.1
+ Revision: 145372
- rebuild

* Wed Jan 02 2008 David Walluck <walluck@mandriva.org> 2.0.11-1mdv2008.1
+ Revision: 140258
- 2.0.11

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Sep 03 2007 Funda Wang <fundawang@mandriva.org> 2.0.1-2mdv2008.0
+ Revision: 78417
- Obsoletes old devel package

* Sun Sep 02 2007 David Walluck <walluck@mandriva.org> 2.0.1-1mdv2008.0
+ Revision: 78359
- Import libsepol

